@@ -97,18 +97,16 @@ Typical usage:
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 0, 3, 'final', 0)
+__version__ = (0, 0, 4, 'final', 0)
 
 __all__ = [
     'Compiler',
-    'helpers',
     'log',
     'strlist',
     ]
 
 from pybars._compiler import (
     Compiler,
-    global_helpers as helpers,
     strlist,
     )
 
